@@ -13,7 +13,6 @@
 #include <core/page.h>
 #include <core/sourcereference.h>
 #include <core/textpage.h>
-#include <core/utils.h>
 
 #include "generator_dvi.h"
 #include "dviFile.h"
@@ -63,7 +62,7 @@ static KAboutData createAboutData()
 OKULAR_EXPORT_PLUGIN( DviGenerator, createAboutData() )
 
 DviGenerator::DviGenerator( QObject *parent, const QVariantList &args ) : Okular::Generator( parent, args ),
-  m_fontExtracted( false ), m_docInfo( 0 ), m_docSynopsis( 0 ), m_dviRenderer( 0 )
+  m_fontExtracted( false ), m_docSynopsis( 0 ), m_dviRenderer( 0 )
 {
     setFeature( Threaded );
     setFeature( TextExtraction );
@@ -122,7 +121,7 @@ bool DviGenerator::loadDocument( const QString & fileName, QVector< Okular::Page
 
     kDebug(DviDebug) << "# of pages:" << m_dviRenderer->dviFile->total_pages;
 
-    m_resolution = Okular::Utils::dpiY();
+    m_resolution = dpi().height();
     loadPages( pagesVector );
 
     return true;
@@ -130,8 +129,6 @@ bool DviGenerator::loadDocument( const QString & fileName, QVector< Okular::Page
 
 bool DviGenerator::doCloseDocument()
 {
-    delete m_docInfo;
-    m_docInfo = 0;
     delete m_docSynopsis;
     m_docSynopsis = 0;
     delete m_dviRenderer;
@@ -335,14 +332,12 @@ Okular::TextPage *DviGenerator::extractTextFromPage( dviPageInfo *pageInfo )
     return ktp;
 }
 
-const Okular::DocumentInfo *DviGenerator::generateDocumentInfo()
+Okular::DocumentInfo DviGenerator::generateDocumentInfo( const QSet<Okular::DocumentInfo::Key> &keys ) const
 {
-    if ( m_docInfo )
-        return m_docInfo;
+    Okular::DocumentInfo docInfo;
 
-    m_docInfo = new Okular::DocumentInfo();
-
-    m_docInfo->set( Okular::DocumentInfo::MimeType, "application/x-dvi" );
+    if ( keys.contains( Okular::DocumentInfo::MimeType ) )
+        docInfo.set( Okular::DocumentInfo::MimeType, "application/x-dvi" );
 
     QMutexLocker lock( userMutex() );
 
@@ -351,12 +346,13 @@ const Okular::DocumentInfo *DviGenerator::generateDocumentInfo()
         dvifile *dvif = m_dviRenderer->dviFile;
 
         // read properties from dvif
-        //m_docInfo->set( "filename", dvif->filename, i18n("Filename") );
-        m_docInfo->set( "generatorDate", dvif->generatorString,
-                       i18n("Generator/Date") );
-        m_docInfo->set( Okular::DocumentInfo::Pages, QString::number( dvif->total_pages ) );
+        //docInfo.set( "filename", dvif->filename, i18n("Filename") );
+        if ( keys.contains( Okular::DocumentInfo::CustomKeys ) )
+            docInfo.set( "generatorDate", dvif->generatorString, i18n("Generator/Date") );
+        if ( keys.contains( Okular::DocumentInfo::Pages ) )
+            docInfo.set( Okular::DocumentInfo::Pages, QString::number( dvif->total_pages ) );
     }
-    return m_docInfo;
+    return docInfo;
 }
 
 const Okular::DocumentSynopsis *DviGenerator::generateDocumentSynopsis()
@@ -541,7 +537,7 @@ void DviGenerator::loadPages( QVector< Okular::Page * > &pagesVector )
         if ( sfa.page < 1 || (int)sfa.page > numofpages )
             continue;
 
-        Okular::NormalizedPoint p( -1.0, (double)sfa.distance_from_top.getLength_in_pixel( Okular::Utils::dpiY() ) / (double)pageRequiredSize.height() );
+        Okular::NormalizedPoint p( -1.0, (double)sfa.distance_from_top.getLength_in_pixel( dpi().height() ) / (double)pageRequiredSize.height() );
         Okular::SourceReference * sourceRef = new Okular::SourceReference( sfa.fileName, sfa.line );
         refRects[ sfa.page - 1 ].append( new Okular::SourceRefObjectRect( p, sourceRef ) );
     }
